@@ -244,24 +244,6 @@ class AccountPaymentSepaTestCase(ModuleTestCase):
                         'identification': same_id,
                         }])
 
-    @with_transaction()
-    def test_sepa_identifier_unique(self):
-        'Test SEPA Creditor Identifier uniqueness'
-        pool = Pool()
-        Party = pool.get('party.party')
-        Identifier = pool.get('party.identifier')
-
-        party = Party(name='test')
-
-        sepa = Identifier(party=party, code='ES23ZZZ47690558N',
-            type='sepa')
-        sepa.save()
-
-        sepa2 = Identifier(party=party, code='ES23ZZZ47690558N',
-            type='sepa')
-        with self.assertRaises(UserError):
-            sepa2.save()
-
     @with_transaction()
     def test_sepa_identifier(self):
         'Test sepa indentifier validation'
@@ -341,7 +323,6 @@ class AccountPaymentSepaTestCase(ModuleTestCase):
             journal = setup_journal('pain.008.001.02', 'receivable',
                 company, company_account)
 
-            self.assertFalse(mandate.has_payments)
             self.assertEqual(mandate.sequence_type, 'FRST')
             mandate.sequence_type_rcur = True
             self.assertEqual(mandate.sequence_type, 'RCUR')
@@ -364,7 +345,6 @@ class AccountPaymentSepaTestCase(ModuleTestCase):
                 _, data = process_payment.do_process(None)
 
             self.assertEqual(payment.sepa_mandate_sequence_type, 'FRST')
-            self.assertTrue(payment.sepa_mandate.has_payments)
 
             payments = Payment.create([{
                         'company': company,
